#
# spec file for package radeontop
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           radeontop
Version:        1.4
Release:        bp155.1.7
Summary:        Tool to view Radeon GPU utilization
License:        GPL-3.0-only
Group:          System/Monitoring
URL:            https://github.com/clbr/radeontop
Source0:        https://github.com/clbr/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        radeontop-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libdrm) >= 2.4.63
BuildRequires:  pkgconfig(libdrm_amdgpu) >= 2.4.79
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-dri2)

%description
A tool to view Radeon GPU utilization, both for the total activity percent
and individual blocks. Supported cards are R600 and up, even Southern
Islands should work fine. Works with both the open drivers and AMD
Catalyst. The total GPU utilization is also valid for OpenCL loads; the
other blocks are only useful in GL loads.

%lang_package

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build debug=1 nostrip=1 amdgpu=1

%install
%make_install LIBDIR=%{_lib}
%find_lang %{name}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_libdir}/lib%{name}_xcb.so
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Dec 20 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.4
  * Update pci ids. Van gogh, yellow carp, navy
    flounder, dimgrey cavefish, aldebaran
  * Install radeontop to /usr/bin
  * Sync translations from launchpad
* Fri Dec 25 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.3
  * Update pci ids, one navi10, new sienna cichlid
  * Update pot file
  * Transparency style fixes
  * Transparency support
  * Update pci ids: arcturus, renoir, navi12, navi14
  * Round the size of the percentage bar to the nearest integer
  * Add Screenshot
  * Refresh man page
  * Add a warning when failing to drop DRM master
  * Add support to open DRM device nodes by pathname
  * Rework of DRM initialization code
  * Add support to discover devices via DRM
  * Move libdrm code to separate functions
  * Warning fix, make the struct copy explicit
  * Move pciaccess code to separate functions
  * Restore libdrm defines, so the non-root-radeon support
    works on older libdrm but new kernel
  * Warning fix, clarify two radeon error messages
  * Update man page
  * Fix matching PCI bus 0 via command line argument
  * Add clock frequency reporting to radeon
  * Check driver version to discover features
  * Move device dependent code to amdgpu.c and radeon.c
  * Move amdgpu code to init_amdgpu() and cleanup_amdgpu()
  * Move radeon initialization code to init_radeon()
  * Revive previously removed radeon_get_drm_value()
  * Use directly the backend functions to get GPU usage
  * Display shader clock on APUs
  * Documentation update for amdgpu and command line
  * Update pci ids from latest kernel, Navi10 support
  * Last commit broke radeon VRAM reading, fix
  * Split getvram() and getgtt() to separate backends
  * Replace amdgpu code with libdrm_amdgpu and autodetect it
  * Add amdgpu backend to getgrbm_device_amdgpu()
  * Split readgrbm() in two seaparate backend functions
  * Move device dependent functions to detect.c
* Fri Dec 20 2019 Martin Pluskal <mpluskal@suse.com>
- Update dependencies
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.2:
  * Add support for new graphic cards and their features
- Add radeontop-rpmlintrc to resolve error for xcb plugin
* Tue Jul 10 2018 mpluskal@suse.com
- Enable building of debuginfo subpackage
* Mon Mar 26 2018 avindra@opensuse.org
- Update to version 1.1
  * pci id updates for polaris12, vega10 and fiji
  * GTT memory reporting
  * appstream info file
  * drop privileges when setuid
- cleanup with spec-cleaner
* Fri Jan 20 2017 vsvecova@suse.com
- Version bump to v1.0
  * Various small fixes
* Thu Nov 24 2016 mpluskal@suse.com
- Update to version 0.9+git.20161028:
  * Add optional unprivileged mode in Xorg
  * Fix auto-detection of radeon device
  * Add a LIBDIR indirection for some x86_64 systems
  * Add support for Polaris 11 and Polaris 10
  * Add support for VRAM size and usage reporting on amdgpu
  * Print "amdgpu not enabled" warning just once
  * Add support for resizeable terminals
  * Fix artifact on mrxvt
  * ui: factor out screen size calculation
  * Silence gcc's "may be uninitialized" warning
* Sun Jul 10 2016 mpluskal@suse.com
- Change dependecies to allow building for SLE-12
* Wed Sep 30 2015 mpluskal@suse.com
- Also install COPYING
* Mon Sep 21 2015 mpluskal@suse.com
- Initial package based on home:Ledest:misc/radeontop
